@@ -8,7 +8,7 @@ use {constants, from_hex, Error, Secp256k1, Signing, Tag};
 ///
 /// Contrary to a [`crate::SecretKey`], the value 0 is also a valid tweak.
 /// Values outside secp curve order are invalid tweaks.
-#[derive(Default, Hash)]
+#[derive(Default)]
 pub struct Tweak([u8; constants::SECRET_KEY_SIZE]);
 impl_array_newtype!(Tweak, u8, constants::SECRET_KEY_SIZE);
 
@@ -177,6 +177,7 @@ impl Generator {
     ///
     /// This is `pub(crate)` because generators have a different serialization from regular public keys.
     /// As such, certain invariants need to be upheld which is easier if we don't allow users to access the internal representation of generators.
+    #[cfg(feature = "std")] // for un-used warnings
     pub(crate) fn as_inner(&self) -> &ffi::PublicKey {
         &self.0
     }
